pub struct ConditionCR {
pub kind: String,
pub status: String,
pub reason: Option<String>,
pub message: Option<String>,
}Fields
kind: Stringstatus: Stringreason: Option<String>message: Option<String>Trait Implementations
Sourceimpl Clone for ConditionCR
impl Clone for ConditionCR
Sourcefn clone(&self) -> ConditionCR
fn clone(&self) -> ConditionCR
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConditionCR
impl Debug for ConditionCR
Sourceimpl<'de> Deserialize<'de> for ConditionCR
impl<'de> Deserialize<'de> for ConditionCR
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&Condition> for ConditionCR
impl From<&Condition> for ConditionCR
Sourceimpl JsonSchema for ConditionCR
impl JsonSchema for ConditionCR
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ConditionCR
impl PartialEq for ConditionCR
Sourceimpl Serialize for ConditionCR
impl Serialize for ConditionCR
impl StructuralPartialEq for ConditionCR