pub struct EscalationLadderCR {
pub tiers: Vec<EscalationTierCR>,
}Fields
tiers: Vec<EscalationTierCR>Trait Implementations
Sourceimpl Clone for EscalationLadderCR
impl Clone for EscalationLadderCR
Sourcefn clone(&self) -> EscalationLadderCR
fn clone(&self) -> EscalationLadderCR
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EscalationLadderCR
impl Debug for EscalationLadderCR
Sourceimpl<'de> Deserialize<'de> for EscalationLadderCR
impl<'de> Deserialize<'de> for EscalationLadderCR
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EscalationLadderCR
impl JsonSchema for EscalationLadderCR
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for EscalationLadderCR
impl PartialEq for EscalationLadderCR
Sourceimpl Serialize for EscalationLadderCR
impl Serialize for EscalationLadderCR
impl StructuralPartialEq for EscalationLadderCR