pub struct ResourceRefCR {
pub cluster: String,
pub namespace: String,
pub name: String,
}Fields
cluster: Stringnamespace: Stringname: StringTrait Implementations
Sourceimpl Clone for ResourceRefCR
impl Clone for ResourceRefCR
Sourcefn clone(&self) -> ResourceRefCR
fn clone(&self) -> ResourceRefCR
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResourceRefCR
impl Debug for ResourceRefCR
Sourceimpl<'de> Deserialize<'de> for ResourceRefCR
impl<'de> Deserialize<'de> for ResourceRefCR
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ResourceRefCR
impl JsonSchema for ResourceRefCR
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ResourceRefCR
impl PartialEq for ResourceRefCR
Sourceimpl Serialize for ResourceRefCR
impl Serialize for ResourceRefCR
impl StructuralPartialEq for ResourceRefCR